@@ -279,12 +279,14 @@ typedef struct gss_config {
 		     OM_uint32,	/* req_output_size */
 		     OM_uint32 *	/* max_input_size */
 	);
+#if defined(ADD_GSSD_PNAME_TO_UID)
                     OM_uint32(*pname_to_uid)
                     (char *,	/* pname */
 		     gss_OID,	/* name type */
 		     gss_OID,	/* mech type */
 		     uid_t *	/* uid */
 	);
+#endif
                     OM_uint32(*gss_duplicate_name)
                     (OM_uint32 *,	/* minor_status */
 		     const gss_name_t,	/* input_name */
@@ -402,8 +404,6 @@ gss_cred_id_t   __gss_get_mechanism_cred(gss_union_cred_t,	/* union_cred
 					 gss_OID	/* mech_type */
     );
 
-OM_uint32       __gss_copy_namebuf(gss_buffer_t src, gss_buffer_t * dest);
-
 OM_uint32       generic_gss_release_oid(OM_uint32 *,	/* minor_status */
 					gss_OID *	/* oid */
     );
